@@ -43,71 +43,6 @@
 #define GET_ANCESTOR(obj) \
     GTK_WINDOW (gtk_widget_get_ancestor (GTK_WIDGET (obj), GTK_TYPE_WINDOW))
 
-void
-nautilus_files_view_handle_uri_list_drop (NautilusFilesView *view,
-                                          const char        *item_uris,
-                                          const char        *target_uri,
-                                          GdkDragAction      action)
-{
-    gchar **uri_list;
-    GList *real_uri_list = NULL;
-    char *container_uri;
-    const char *real_target_uri;
-    int n_uris, i;
-
-    if (item_uris == NULL)
-    {
-        return;
-    }
-
-    container_uri = NULL;
-    if (target_uri == NULL)
-    {
-        container_uri = nautilus_files_view_get_backing_uri (view);
-        g_assert (container_uri != NULL);
-    }
-
-    if (action == GDK_ACTION_ASK)
-    {
-#if 0 && NAUTILUS_DND_NEEDS_GTK4_REIMPLEMENTATION
-        action = nautilus_drag_drop_action_ask
-                     (GTK_WIDGET (view),
-                     GDK_ACTION_MOVE | GDK_ACTION_COPY | GDK_ACTION_LINK);
-        if (action == 0)
-#endif
-        {
-            g_free (container_uri);
-            return;
-        }
-    }
-
-    n_uris = 0;
-    uri_list = g_uri_list_extract_uris (item_uris);
-    for (i = 0; uri_list[i] != NULL; i++)
-    {
-        real_uri_list = g_list_append (real_uri_list, uri_list[i]);
-        n_uris++;
-    }
-    g_free (uri_list);
-
-    /* do nothing if no real uris are left */
-    if (n_uris == 0)
-    {
-        g_free (container_uri);
-        return;
-    }
-
-    real_target_uri = target_uri != NULL ? target_uri : container_uri;
-
-    nautilus_files_view_move_copy_items (view, real_uri_list,
-                                         real_target_uri,
-                                         action);
-
-    g_list_free_full (real_uri_list, g_free);
-
-    g_free (container_uri);
-}
-
 #define MAX_LEN_FILENAME 64
 #define MIN_LEN_FILENAME 8
 
@@ -193,7 +128,7 @@ nautilus_files_view_handle_text_drop (NautilusFilesView *view,
                                       const char        *target_uri,
                                       GdkDragAction      action)
 {
-    int length;
+    gsize length;
     char *container_uri;
     char *filename;
 
@@ -225,53 +160,6 @@ nautilus_files_view_handle_text_drop (NautilusFilesView *view,
     g_free (container_uri);
 }
 
-void
-nautilus_files_view_handle_raw_drop (NautilusFilesView *view,
-                                     const char        *raw_data,
-                                     int                length,
-                                     const char        *target_uri,
-                                     const char        *direct_save_uri,
-                                     GdkDragAction      action)
-{
-    char *container_uri, *filename;
-    GFile *direct_save_full;
-
-    if (raw_data == NULL)
-    {
-        return;
-    }
-
-    g_return_if_fail (action == GDK_ACTION_COPY);
-
-    container_uri = NULL;
-    if (target_uri == NULL)
-    {
-        container_uri = nautilus_files_view_get_backing_uri (view);
-        g_assert (container_uri != NULL);
-    }
-
-    filename = NULL;
-    if (direct_save_uri != NULL)
-    {
-        direct_save_full = g_file_new_for_uri (direct_save_uri);
-        filename = g_file_get_basename (direct_save_full);
-    }
-    if (filename == NULL)
-    {
-        /* Translator: This is the filename used for when you dnd raw
-         * data to a directory, if the source didn't supply a name.
-         */
-        filename = g_strdup (_("dropped data"));
-    }
-
-    nautilus_files_view_new_file_with_initial_contents (
-        view, target_uri != NULL ? target_uri : container_uri,
-        filename, raw_data, length);
-
-    g_free (container_uri);
-    g_free (filename);
-}
-
 void
 nautilus_files_view_drop_proxy_received_uris (NautilusFilesView *view,
                                               const GList       *source_uri_list,
@@ -307,23 +195,6 @@ nautilus_files_view_drop_proxy_received_uris (NautilusFilesView *view,
         return;
     }
 
-    if (action == GDK_ACTION_ASK)
-    {
-#if 0 && NAUTILUS_DND_NEEDS_GTK4_REIMPLEMENTATION
-        action = nautilus_drag_drop_action_ask
-                     (GTK_WIDGET (view),
-                     GDK_ACTION_MOVE | GDK_ACTION_COPY | GDK_ACTION_LINK);
-        if (action == 0)
-#endif
-        {
-            return;
-        }
-    }
-
-#if 0 && NAUTILUS_DND_NEEDS_GTK4_REIMPLEMENTATION
-    nautilus_clipboard_clear_if_colliding_uris (GTK_WIDGET (view),
-                                                source_uri_list);
-#endif
     nautilus_files_view_move_copy_items (view, source_uri_list,
                                          target_uri != NULL ? target_uri : container_uri,
                                          action);
