@@ -23,7 +23,7 @@ struct _NautilusGridView
 
     GQuark caption_attributes[NAUTILUS_GRID_CELL_N_CAPTIONS];
 
-    NautilusFileSortType sort_type;
+    GQuark sort_attribute;
     gboolean reversed;
 };
 
@@ -43,10 +43,10 @@ nautilus_grid_view_sort (gconstpointer a,
     file_a = nautilus_view_item_get_file (NAUTILUS_VIEW_ITEM ((gpointer) a));
     file_b = nautilus_view_item_get_file (NAUTILUS_VIEW_ITEM ((gpointer) b));
 
-    return nautilus_file_compare_for_sort (file_a, file_b,
-                                           self->sort_type,
-                                           self->directories_first,
-                                           self->reversed);
+    return nautilus_file_compare_for_sort_by_attribute_q (file_a, file_b,
+                                                          self->sort_attribute,
+                                                          self->directories_first,
+                                                          self->reversed);
 }
 
 static void
@@ -373,7 +373,7 @@ action_sort_order_changed (GSimpleAction *action,
     }
 
     g_variant_get (value, "(&sb)", &target_name, &self->reversed);
-    self->sort_type = get_sorts_type_from_metadata_text (target_name);
+    self->sort_attribute = g_quark_from_string (target_name);
 
     sorter = gtk_custom_sorter_new (nautilus_grid_view_sort, self, NULL);
     model = nautilus_list_base_get_model (NAUTILUS_LIST_BASE (self));
@@ -441,10 +441,11 @@ bind_cell (GtkSignalListItemFactory *factory,
            gpointer                  user_data)
 {
     GtkWidget *cell;
-    NautilusViewItem *item;
+    g_autoptr (NautilusViewItem) item = NULL;
 
     cell = gtk_list_item_get_child (listitem);
-    item = NAUTILUS_VIEW_ITEM (gtk_list_item_get_item (listitem));
+    item = listitem_get_view_item (listitem);
+    g_return_if_fail (item != NULL);
 
     nautilus_view_item_set_item_ui (item, cell);
 
@@ -474,11 +475,15 @@ unbind_cell (GtkSignalListItemFactory *factory,
              GtkListItem              *listitem,
              gpointer                  user_data)
 {
-    NautilusViewItem *item;
+    g_autoptr (NautilusViewItem) item = NULL;
 
-    item = NAUTILUS_VIEW_ITEM (gtk_list_item_get_item (listitem));
+    item = listitem_get_view_item (listitem);
 
-    nautilus_view_item_set_item_ui (item, NULL);
+    /* item may be NULL when row has just been destroyed. */
+    if (item != NULL)
+    {
+        nautilus_view_item_set_item_ui (item, NULL);
+    }
 }
 
 static void
@@ -491,6 +496,7 @@ setup_cell (GtkSignalListItemFactory *factory,
 
     cell = nautilus_grid_cell_new (NAUTILUS_LIST_BASE (self));
     setup_cell_common (listitem, NAUTILUS_VIEW_CELL (cell));
+    setup_cell_hover (NAUTILUS_VIEW_CELL (cell));
 
     nautilus_grid_cell_set_caption_attributes (cell, self->caption_attributes);
 }
