@@ -7,6 +7,8 @@
 #include "nautilus-name-cell.h"
 #include "nautilus-file-utilities.h"
 
+#define LOADING_TIMEOUT_SECONDS 1
+
 struct _NautilusNameCell
 {
     NautilusViewCell parent_instance;
@@ -16,7 +18,10 @@ struct _NautilusNameCell
     GQuark path_attribute_q;
     GFile *file_path_base_location;
 
+    GtkWidget *expander;
+    GtkWidget *content;
     GtkWidget *fixed_height_box;
+    GtkWidget *spinner;
     GtkWidget *icon;
     GtkWidget *label;
     GtkWidget *emblems_box;
@@ -25,6 +30,7 @@ struct _NautilusNameCell
     GtkWidget *path;
 
     gboolean show_snippet;
+    guint loading_timeout_id;
 };
 
 G_DEFINE_TYPE (NautilusNameCell, nautilus_name_cell, NAUTILUS_TYPE_VIEW_CELL)
@@ -124,7 +130,6 @@ update_icon (NautilusNameCell *self)
 {
     NautilusFileIconFlags flags;
     g_autoptr (GdkPaintable) icon_paintable = NULL;
-    GtkStyleContext *style_context;
     g_autoptr (NautilusViewItem) item = NULL;
     NautilusFile *file;
     guint icon_size;
@@ -160,17 +165,16 @@ update_icon (NautilusNameCell *self)
     gtk_widget_set_margin_top (self->fixed_height_box, extra_margin);
     gtk_widget_set_margin_bottom (self->fixed_height_box, extra_margin);
 
-    style_context = gtk_widget_get_style_context (self->icon);
     thumbnail_path = nautilus_file_get_thumbnail_path (file);
     if (icon_size >= NAUTILUS_THUMBNAIL_MINIMUM_ICON_SIZE &&
         thumbnail_path != NULL &&
         nautilus_file_should_show_thumbnail (file))
     {
-        gtk_style_context_add_class (style_context, "thumbnail");
+        gtk_widget_add_css_class (self->icon, "thumbnail");
     }
     else
     {
-        gtk_style_context_remove_class (style_context, "thumbnail");
+        gtk_widget_remove_css_class (self->icon, "thumbnail");
     }
 }
 
@@ -269,6 +273,48 @@ on_item_is_cut_changed (NautilusNameCell *self)
     }
 }
 
+static gboolean
+on_loading_timeout (gpointer user_data)
+{
+    NautilusNameCell *self = NAUTILUS_NAME_CELL (user_data);
+    gboolean is_loading;
+
+    self->loading_timeout_id = 0;
+
+    g_object_get (nautilus_view_cell_get_item (NAUTILUS_VIEW_CELL (self)),
+                  "is-loading", &is_loading,
+                  NULL);
+    if (is_loading)
+    {
+        gtk_widget_set_visible (self->spinner, TRUE);
+        gtk_spinner_start (GTK_SPINNER (self->spinner));
+    }
+
+    return G_SOURCE_REMOVE;
+}
+
+static void
+on_item_is_loading_changed (NautilusNameCell *self)
+{
+    gboolean is_loading;
+    NautilusViewItem *item = nautilus_view_cell_get_item (NAUTILUS_VIEW_CELL (self));
+
+
+    g_clear_handle_id (&self->loading_timeout_id, g_source_remove);
+    g_object_get (item, "is-loading", &is_loading, NULL);
+    if (is_loading)
+    {
+        self->loading_timeout_id = g_timeout_add_seconds (LOADING_TIMEOUT_SECONDS,
+                                                          G_SOURCE_FUNC (on_loading_timeout),
+                                                          self);
+    }
+    else
+    {
+        gtk_widget_set_visible (self->spinner, FALSE);
+        gtk_spinner_stop (GTK_SPINNER (self->spinner));
+    }
+}
+
 static void
 nautilus_name_cell_init (NautilusNameCell *self)
 {
@@ -282,6 +328,8 @@ nautilus_name_cell_init (NautilusNameCell *self)
                                     (GCallback) on_item_drag_accept_changed, self);
     g_signal_group_connect_swapped (self->item_signal_group, "notify::is-cut",
                                     (GCallback) on_item_is_cut_changed, self);
+    g_signal_group_connect_swapped (self->item_signal_group, "notify::is-loading",
+                                    (GCallback) on_item_is_loading_changed, self);
     g_signal_group_connect_swapped (self->item_signal_group, "file-changed",
                                     (GCallback) on_file_changed, self);
     g_signal_connect_object (self->item_signal_group, "bind",
@@ -313,7 +361,10 @@ nautilus_name_cell_class_init (NautilusNameCellClass *klass)
 
     gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/nautilus/ui/nautilus-name-cell.ui");
 
+    gtk_widget_class_bind_template_child (widget_class, NautilusNameCell, expander);
+    gtk_widget_class_bind_template_child (widget_class, NautilusNameCell, content);
     gtk_widget_class_bind_template_child (widget_class, NautilusNameCell, fixed_height_box);
+    gtk_widget_class_bind_template_child (widget_class, NautilusNameCell, spinner);
     gtk_widget_class_bind_template_child (widget_class, NautilusNameCell, icon);
     gtk_widget_class_bind_template_child (widget_class, NautilusNameCell, label);
     gtk_widget_class_bind_template_child (widget_class, NautilusNameCell, emblems_box);
@@ -344,3 +395,15 @@ nautilus_name_cell_show_snippet (NautilusNameCell *self)
 {
     self->show_snippet = TRUE;
 }
+
+GtkTreeExpander *
+nautilus_name_cell_get_expander (NautilusNameCell *self)
+{
+    return GTK_TREE_EXPANDER (self->expander);
+}
+
+GtkWidget *
+nautilus_name_cell_get_content (NautilusNameCell *self)
+{
+    return self->content;
+}
